%define major		1
%define libname		%mklibname lxc %{major}
%define develname	%mklibname lxc -d

Name:		lxc
Epoch:		1
Version:	4.0.11
Release:	%mkrel 1
Summary:	Linux Containers
Group:		System/Kernel and hardware
License:	LGPLv2+ and GPLv2
URL:		https://linuxcontainers.org
Source0:	https://linuxcontainers.org/downloads/%{name}/%{name}-%{version}.tar.gz
Patch1:		lxc-4.0.6-fix-bootorder.patch
# Mga patches:
Patch10:        add-mga-support.patch

BuildRequires:	docbook-utils
BuildRequires:	docbook-dtd30-sgml
BuildRequires:	docbook2x
BuildRequires:	doxygen
BuildRequires:	kernel-headers
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	pkgconfig(libseccomp)
BuildRequires:	pkgconfig(libselinux)
BuildRequires:	pkgconfig(libcap)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(systemd)
BuildRequires:	graphviz

# lxc-extra subpackage not needed anymore, lxc-ls has been rewriten in
# C and does not depend on the Python3 binding anymore
Provides:       lxc-extra = %{epoch}:%{version}-%{release}
Obsoletes:      lxc-extra < 1:1.1.5-7

%{!?_pkgdocdir: %global _pkgdocdir %_defaultdocdir/%name}

%description
The package "%{name}" provides the command lines to create and manage
containers.  It contains a full featured container with the isolation
/ virtualization of the pids, the ipc, the utsname, the mount points,
/proc, /sys, the network and it takes into account the control groups.
It is very light, flexible, and provides a set of tools around the
container like the monitoring with asynchronous events notification,
or the freeze of the container. This package is useful to create
Virtual Private Server, or to run isolated applications like bash or
sshd.

%package -n	%{libname}
Summary:	Library for LXC
Group:		System/Libraries

%description -n %{libname}
Library for the Linux Kernel Containers.


%package -n	%{develname}
Summary:	Development files for LXC
Group:		Development/C
Requires:	%{libname} >= %{epoch}:%{version}-%{release}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}

%description -n %{develname}
Development files for the Linux Kernel Containers.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description    doc
This package contains documentation for %{name}.


%prep
%setup -q
%autopatch -p1


%build
# (tv) for mga patch:
./autogen.sh
%configure --with-distro=mageia \
           --enable-doc \
           --enable-api-docs \
           --disable-silent-rules \
           --docdir=%{_pkgdocdir} \
           --disable-rpath \
           --disable-static \
           --disable-apparmor \
           --enable-selinux \
           --enable-capabilities \
           --enable-pam \
           --enable-openssl \
           --enable-seccomp \
           --with-init-script=systemd \
           --disable-werror

%make_build


%install
%make_install
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}

# docs
mkdir -p %{buildroot}%{_pkgdocdir}/api
cp -a AUTHORS README %{buildroot}%{_pkgdocdir}
cp -a doc/api/html/* %{buildroot}%{_pkgdocdir}/api/

# remove libtool .la file
rm -rf %{buildroot}%{_libdir}/liblxc.la

# cache dir
mkdir -p %{buildroot}%{_localstatedir}/cache/%{name}

%find_lang %{name} --with-man --all-name

%check
make check


%files -f %{name}.lang
%{_bindir}/lxc-*
%{_sbindir}/*lxc*
%{_libexecdir}/lxc
%{_datadir}/lxc
%{_mandir}/man*/%{name}*
%{_mandir}/man8/pam_cgfs.8.*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/default.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_sharedstatedir}/lxc
%{_libdir}/lxc/rootfs
%{_unitdir}/lxc-net.service
%{_unitdir}/%{name}@.service
%{_unitdir}/lxc.service
%{_datadir}/bash-completion/completions/%{name}*
%dir %{_localstatedir}/cache/%{name}
/%{_lib}/security/pam_cgfs.so

%files -n %{libname}
%dir %{_pkgdocdir}
%{_pkgdocdir}/AUTHORS
%{_pkgdocdir}/README
%license COPYING
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{major}.*
%dir %{_libdir}/lxc

%files -n %{develname}
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/lxc
%{_libdir}/liblxc.so

%files doc
%dir %{_pkgdocdir}
# README, AUTHORS and COPYING intentionally duplicated because -doc
# can be installed on its own.
%{_pkgdocdir}/*
%license COPYING


%changelog
* Sun Nov 14 2021 buchan <buchan> 1:4.0.11-1.mga8
+ Revision: 1756425
+ rebuild (emptylog)

* Mon Nov 01 2021 buchan <buchan> 1:4.0.11-1.mga9
+ Revision: 1753593
- Update to 4.0.11
+ wally <wally>
- rebuild for openssl 3.0.0

* Wed May 05 2021 daviddavid <daviddavid> 1:4.0.9-1.mga9
+ Revision: 1721414
- new version: 4.0.9

* Sat May 01 2021 daviddavid <daviddavid> 1:4.0.8-1.mga9
+ Revision: 1720699
- new version: 4.0.8

* Thu Mar 11 2021 daviddavid <daviddavid> 1:4.0.6-1.mga9
+ Revision: 1701383
- new version: 4.0.6

* Thu Mar 11 2021 daviddavid <daviddavid> 1:3.2.1-1.mga9
+ Revision: 1701318
- new version: 3.2.1
- now lua, python and templates are in their own packages

* Mon Oct 19 2020 akien <akien> 1:2.0.9-8.mga8
+ Revision: 1636877
- Rebuild for lua 5.3

* Sun Feb 16 2020 umeabot <umeabot> 1:2.0.9-7.mga8
+ Revision: 1531415
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Sep 12 2019 wally <wally> 1:2.0.9-6.mga8
+ Revision: 1440035
- rebuild for python3.8
- fix linking with lua

* Tue Feb 12 2019 luigiwalser <luigiwalser> 1:2.0.9-5.mga7
+ Revision: 1365398
- add upstream patches including one to fix CVE-2019-5736

* Tue Jan 08 2019 daviddavid <daviddavid> 1:2.0.9-4.mga7
+ Revision: 1352865
- rebuild for new Python 3.7

* Fri Oct 26 2018 bcornec <bcornec> 1:2.0.9-3.mga7
+ Revision: 1325579
- Fix again bash completion delivery as it seems different on different arches !
- patches for CVE in mga#23400
- Fix build issue with bash-completion and CVE in mga#23400

* Sun Sep 23 2018 umeabot <umeabot> 1:2.0.9-2.mga7
+ Revision: 1299394
- Mageia 7 Mass Rebuild

* Sat Jun 30 2018 joequant <joequant> 1:2.0.9-1.mga7
+ Revision: 1240836
- upgrade to 2.0.9

* Fri Sep 15 2017 cjw <cjw> 1:2.0.8-3.mga7
+ Revision: 1154227
- buildrequires: lua5.2-devel to match file list

* Sat Aug 05 2017 pterjan <pterjan> 1:2.0.8-2.mga7
+ Revision: 1135268
- Rebuild for python 3.6

* Sun Jun 04 2017 luigiwalser <luigiwalser> 1:2.0.8-1.mga6
+ Revision: 1106652
- 2.0.8 (fixes CVE-2017-5985)
- do not patch SysV init scripts anymore
- replace patch 2 with a configure argument
- remove upstreamed CVE-2016-8649 patch
- rediff patch 1

* Sun Jun 04 2017 luigiwalser <luigiwalser> 1:2.0.0-6.mga6
+ Revision: 1106627
- rediff patch from ubuntu to fix CVE-2016-8649

* Fri Apr 22 2016 tv <tv> 1:2.0.0-5.mga6
+ Revision: 1004679
- really adjusb obsoletes

* Fri Apr 22 2016 tv <tv> 1:2.0.0-4.mga6
+ Revision: 1004551
- adjusb obsoletes

* Thu Apr 21 2016 tv <tv> 1:2.0.0-3.mga6
+ Revision: 1004194
- really fix upgrade (epoch!)

* Thu Apr 21 2016 tv <tv> 1:2.0.0-2.mga6
+ Revision: 1004116
- fix upgrade: conflicts with lxc-extra instead of just provides+obsoletes
+ philippem <philippem>
- add BR on graphviz

* Thu Apr 21 2016 tv <tv> 1:2.0.0-1.mga6
+ Revision: 1004054
- adjust file list
- rediff mga support patch
- update to 2.0.0
- obsolete the -extra subpackage
- move the completion file to %%{_datadir}

* Thu Mar 31 2016 tv <tv> 1:1.1.5-6.mga6
+ Revision: 997053
- own cache dir
- run testsuite
- add a doc package
- add patches from FC
- enable lua bindings
- use standard macros for building
- enable seccomp support
- simpler solution for rpath error
- onw include directory

* Wed Mar 30 2016 tv <tv> 1:1.1.5-4.mga6
+ Revision: 996817
- enable python bindings
- split tools now using python instead of shell in extra pkg

* Tue Mar 29 2016 tv <tv> 1:1.1.5-2.mga6
+ Revision: 996303
- BR ssystemd-devel
- explicitely specify we use systemd (though it's now autocomputed as part of mga support)
- add a mageia template
- adjust file list for systemd

* Tue Mar 29 2016 tv <tv> 1:1.1.5-1.mga6
+ Revision: 996289
- new release

* Mon Feb 15 2016 umeabot <umeabot> 1:1.1.4-2.mga6
+ Revision: 961314
- Mageia 6 Mass Rebuild

* Fri Oct 23 2015 joequant <joequant> 1:1.1.4-1.mga6
+ Revision: 894362
- upgrade to 1.1.4

* Thu Oct 22 2015 luigiwalser <luigiwalser> 1:1.0.5-6.mga6
+ Revision: 894299
- rediff patch from opensuse to fix CVE-2015-1335

* Tue Oct 20 2015 tv <tv> 1:1.0.5-5.mga6
+ Revision: 893158
- fix build: package more docs

* Mon Jul 27 2015 luigiwalser <luigiwalser> 1:1.0.5-4.mga6
+ Revision: 858315
- add upstream patches to fix CVE-2015-1331 and CVE-2015-1334

* Wed Oct 15 2014 umeabot <umeabot> 1:1.0.5-3.mga5
+ Revision: 745826
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:1.0.5-2.mga5
+ Revision: 682063
- Mageia 5 Mass Rebuild

* Sun Aug 10 2014 sander85 <sander85> 1:1.0.5-1.mga5
+ Revision: 661498
- New version: 1.0.5

* Mon Jun 16 2014 sander85 <sander85> 1:1.0.4-1.mga5
+ Revision: 637608
- New version: 1.0.4

* Fri May 16 2014 tv <tv> 1:1.0.3-1.mga5
+ Revision: 622964
- adjust file list
- new release

* Wed Feb 26 2014 blino <blino> 1:1.0.0-4.mga5
+ Revision: 597457
- fix again conflicts by using older libname

* Wed Feb 26 2014 blino <blino> 1:1.0.0-3.mga5
+ Revision: 597283
- fix conflict with lib package by using epoch

* Mon Feb 24 2014 tv <tv> 1:1.0.0-2.mga5
+ Revision: 596160
- fix unversioned file in library package (mga#12864)

* Sun Feb 23 2014 tv <tv> 1:1.0.0-1.mga5
+ Revision: 595958
- workaround find_lang failure with --with-man
- adjust file list
- bump major
- fix files listed twice
- drop merged patches
- new release
- new URL

* Thu Feb 13 2014 luigiwalser <luigiwalser> 1:0.9.0-6.mga5
+ Revision: 590883
- rediff upstream patch to fix CVE-2013-6441

* Mon Jan 13 2014 danf <danf> 1:0.9.0-5.mga4
+ Revision: 566524
- Added destroy-check.patch to prevent damage if a container is destroyed
  without being completely stopped
- Packaged missing /var/lib/lxc

* Sun Dec 29 2013 boklm <boklm> 1:0.9.0-4.mga4
+ Revision: 563089
- Fix location of rootfs directory

* Fri Nov 08 2013 boklm <boklm> 1:0.9.0-3.mga4
+ Revision: 549914
- Build man pages
- Install templates in default directory

* Sat Oct 19 2013 umeabot <umeabot> 1:0.9.0-2.mga4
+ Revision: 523897
- Mageia 4 Mass Rebuild

* Sun May 26 2013 tv <tv> 1:0.9.0-1.mga4
+ Revision: 427786
- fix install
- adjust file list
- new release

* Mon Apr 01 2013 tv <tv> 1:0.8.0-1.mga3
+ Revision: 407033
- new release
- disable apparmor (fix build)
- adjust filelist
- add epoch due to bogus prior packaging

* Sun Jan 13 2013 luigiwalser <luigiwalser> 0.8.0rc2-3.mga3
+ Revision: 362115
- make use of _libexecdir and fix files list
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 08 2012 bcornec <bcornec> 0.8.0rc2-2.mga3
+ Revision: 316437
- Force a new release tag for lxc to have it rebuilt with the new tar file
- Update bad tar source file for lxc
- Update to upstream 0.8.0-rc2

* Sun Sep 04 2011 misc <misc> 0.7.5-1.mga2
+ Revision: 138350
- fix group and summary of lxc-devel
- obsoletes the lxc-doc package, as it is just 16 kb
- remove useless BuildRequires
- do not regenerate configure without reason
- comment the rpath stuff
- drop uneeded define
- new version, thanks bogdano for noticing

* Wed Jun 29 2011 tv <tv> 0.7.4.2-1.mga2
+ Revision: 116124
- fix build
- Buildrequires:  docbook-dtd30-sgml
- BR kernel-headers instead of kernel-devel-latest
- new release
- fix group for doc package
+ ahmad <ahmad>
- define path to kernel src dir manually
+ boklm <boklm>
- rebuild for bug #497

* Mon Mar 07 2011 saispo <saispo> 0.7.4-2.mga1
+ Revision: 65992
- Bump release
- Fix template installation
- Add doc and fix build
- New release 0.7.4
+ boklm <boklm>
- add SOURCES directory
- add lxc

